@@ -58,9 +58,7 @@ using namespace Akonadi;
 class FolderTreeWidgetTest : public QObject
 {
     Q_OBJECT
-public:
-
-private slots:
+private Q_SLOTS:
     void initTestCase()
     {
         AkonadiTest::checkTestIsIsolated();
